@@ -14,7 +14,7 @@ from ansible_runner.config.runner import RunnerConfig, ExecutionMode
 from ansible_runner.interface import init_runner
 from ansible_runner.loader import ArtifactLoader
 from ansible_runner.exceptions import ConfigurationError
-from ansible_runner.utils import callback_mount
+from test.utils.common import RSAKey
 
 try:
     Pattern = re._pattern_type
@@ -185,13 +185,14 @@ def test_prepare_env_sshkey(mocker):
     mocker.patch('os.makedirs', return_value=True)
     rc = RunnerConfig('/')
 
-    value = '01234567890'
-    sshkey_side_effect = partial(load_file_side_effect, 'env/ssh_key', value)
+    rsa_key = RSAKey()
+    rsa_private_key_value = rsa_key.private
+    sshkey_side_effect = partial(load_file_side_effect, 'env/ssh_key', rsa_private_key_value)
 
     mocker.patch.object(rc.loader, 'load_file', side_effect=sshkey_side_effect)
 
     rc.prepare_env()
-    assert rc.ssh_key_data == value
+    assert rc.ssh_key_data == rsa_private_key_value
 
 
 def test_prepare_env_defaults(mocker):
@@ -479,7 +480,8 @@ def test_prepare_with_ssh_key(mocker):
     rc.env = {}
     rc.execution_mode = ExecutionMode.ANSIBLE_PLAYBOOK
     rc.playbook = 'main.yaml'
-    rc.ssh_key_data = '01234567890'
+    rsa_key = RSAKey()
+    rc.ssh_key_data = rsa_key.private
     rc.command = 'ansible-playbook'
 
     mocker.patch.dict('os.environ', {'AWX_LIB_DIRECTORY': '/'})
@@ -715,6 +717,11 @@ def test_containerization_settings(tmp_path, runtime, mocker):
     mock_containerized = mocker.patch('ansible_runner.runner_config.RunnerConfig.containerized', new_callable=mocker.PropertyMock)
     mock_containerized.return_value = True
 
+    # In this test get_callback_dir() will not return a callback plugin dir that exists
+    # mock shutil.copytree and shutil.rmtree to just return True instead of trying to copy
+    mocker.patch('shutil.copytree', return_value=True)
+    mocker.patch('shutil.rmtree', return_value=True)
+
     rc = RunnerConfig(tmp_path)
     rc.ident = 'foo'
     rc.playbook = 'main.yaml'
@@ -725,6 +732,14 @@ def test_containerization_settings(tmp_path, runtime, mocker):
     rc.container_volume_mounts = ['/host1:/container1', '/host2:/container2']
     rc.prepare()
 
+    # validate ANSIBLE_CALLBACK_PLUGINS env var is set
+    assert rc.env.get('ANSIBLE_CALLBACK_PLUGINS', None) is not None
+
+    # validate ANSIBLE_CALLBACK_PLUGINS contains callback plugin dir
+    callback_plugins = rc.env['ANSIBLE_CALLBACK_PLUGINS'].split(':')
+    callback_dir = os.path.join("/runner/artifacts", "{}".format(rc.ident), "callback")
+    assert callback_dir in callback_plugins
+
     extra_container_args = []
     if runtime == 'podman':
         extra_container_args = ['--quiet']
@@ -733,7 +748,6 @@ def test_containerization_settings(tmp_path, runtime, mocker):
 
     expected_command_start = [runtime, 'run', '--rm', '--tty', '--interactive', '--workdir', '/runner/project'] + \
         ['-v', '{}/:/runner/:Z'.format(rc.private_data_dir)] + \
-        ['-v', '{0}:{1}:Z'.format(*callback_mount())] + \
         ['-v', '/host1/:/container1/', '-v', '/host2/:/container2/'] + \
         ['--env-file', '{}/env.list'.format(rc.artifact_dir)] + \
         extra_container_args + \
